//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by amaya.rc
//
#define LINKDIALOG                      101
#define PRINTDIALOG                     103
#define SEARCHDIALOG                    104
#define CLOSEDOCDIALOG                  109
#define OPENDOCDIALOG                   110
#define CHARACTERSDIALOG                112
#define INITCONFIRMDIALOG               144
#define FORMATDIALOG                    146
#define IDB_BINDENT1                    150
#define IDB_BINDENT2                    151
#define IDB_BSSMALL                     152
#define IDB_BSMEDIUM                    153
#define IDB_BSLARGE                     154
#define IDR_TOOLBAR1                    165
#define SPELLCHECKDIALOG                169
#define CREATERULEDIALOG                170
#define APPLYCLASSDIALOG                171
#define LANGUAGEDIALOG                  172
#define ATTR5ITEMSDIALOG                173
#define SAVEASDIALOG                    174
#define AUTHENTIFICATIONDIALOG          175
#define ATTR3ITEMSDIALOG                176
#define HELPDIALOG                      181
#define IDB_AMAYALOGO                   182
#define IDB_MATH                        183
#define IDB_MATHD                       184
#define IDB_ROOT                        185
#define IDB_SROOT                       186
#define IDB_DIV                         187
#define IDB_POWIND                      188
#define IDB_POW                         189
#define IDB_IND                         190
#define IDB_UPDN                        191
#define IDB_UP                          192
#define IDB_DOWN                        193
#define IDB_PAREXP                      194
#define IDB_UDLR                        195
#define IDB_SYM                         196
#define MATHDIALOG                      199
#define IDB_GKEY001                     200
#define IDB_GKEY002                     201
#define IDB_GKEY003                     202
#define IDB_GKEY004                     203
#define IDB_GKEY005                     204
#define IDB_GKEY006                     205
#define IDB_GKEY007                     206
#define IDB_GKEY008                     207
#define IDB_GKEY009                     208
#define IDB_GKEY010                     209
#define IDB_GKEY011                     210
#define IDB_GKEY012                     211
#define IDB_GKEY013                     212
#define IDB_GKEY014                     216
#define IDB_GKEY015                     217
#define IDB_GKEY016                     218
#define IDB_GKEY017                     219
#define IDB_GKEY018                     220
#define IDB_GKEY019                     221
#define IDB_GKEY020                     222
#define IDB_GKEY021                     223
#define IDB_GKEY022                     224
#define IDB_GKEY023                     225
#define IDB_GKEY024                     226
#define IDB_GKEY025                     227
#define IDB_GKEY026                     228
#define IDB_GKEY027                     229
#define IDB_GKEY028                     230
#define IDB_GKEY029                     231
#define IDB_GKEY030                     232
#define IDB_GKEY031                     233
#define IDB_GKEY032                     234
#define IDB_GKEY033                     235
#define IDB_GKEY034                     236
#define IDB_GKEY035                     237
#define IDB_GKEY036                     238
#define IDB_GKEY037                     239
#define IDB_GKEY038                     240
#define IDB_GKEY039                     241
#define IDB_GKEY040                     242
#define IDB_GKEY041                     243
#define IDB_GKEY042                     244
#define IDB_GKEY043                     245
#define IDB_GKEY044                     246
#define IDB_GKEY045                     247
#define IDB_GKEY046                     248
#define IDB_GKEY047                     249
#define IDB_GKEY048                     250
#define IDB_GKEY049                     251
#define IDB_GKEY050                     252
#define IDB_GKEY051                     253
#define IDB_GKEY052                     254
#define IDB_GKEY053                     255
#define IDB_GKEY054                     256
#define IDB_GKEY055                     257
#define IDB_GKEY056                     258
#define IDB_GKEY057                     259
#define IDB_GKEY058                     260
#define IDB_GKEY059                     261
#define IDB_GKEY060                     262
#define IDB_GKEY061                     263
#define IDB_GKEY062                     264
#define IDB_GKEY063                     265
#define IDB_GKEY064                     266
#define IDB_GKEY065                     267
#define IDB_GKEY066                     268
#define IDB_GKEY067                     269
#define IDB_GKEY068                     270
#define IDB_GKEY069                     271
#define IDB_GKEY070                     272
#define IDB_GKEY071                     273
#define IDB_GKEY072                     274
#define IDB_GKEY073                     275
#define IDB_GKEY074                     276
#define IDB_GKEY075                     277
#define IDB_GKEY076                     278
#define IDB_GKEY077                     279
#define IDB_GKEY078                     280
#define IDB_GKEY079                     281
#define IDB_GKEY080                     282
#define IDB_GKEY081                     283
#define IDB_GKEY082                     284
#define IDB_GKEY083                     285
#define IDB_GKEY084                     286
#define IDB_GKEY085                     287
#define IDB_GKEY086                     288
#define IDB_GKEY087                     289
#define IDB_GKEY088                     290
#define IDB_GKEY089                     291
#define IDB_GKEY090                     292
#define IDB_GKEY091                     293
#define IDB_GKEY092                     294
#define IDB_GKEY093                     295
#define IDB_GKEY094                     296
#define IDB_GKEY095                     297
#define IDB_GKEY096                     298
#define IDB_GKEY097                     299
#define IDB_GKEY098                     300
#define IDB_GKEY099                     301
#define IDB_GKEY100                     302
#define IDB_GKEY101                     303
#define IDB_GKEY102                     304
#define IDB_GKEY103                     305
#define IDB_GKEY104                     306
#define IDB_GKEY105                     307
#define IDB_GKEY106                     308
#define IDB_GKEY107                     309
#define IDB_GKEY108                     310
#define IDB_GKEY109                     311
#define IDB_GKEY110                     312
#define IDB_GKEY111                     313
#define IDB_GKEY112                     314
#define IDB_GKEY113                     315
#define IDB_GKEY114                     316
#define IDB_GKEY115                     317
#define IDB_GKEY116                     318
#define IDB_GKEY117                     319
#define IDB_GKEY118                     320
#define IDB_GKEY119                     321
#define IDB_GKEY120                     322
#define IDB_GKEY121                     323
#define IDB_GKEY122                     324
#define IDB_GKEY123                     325
#define IDB_GKEY124                     326
#define IDB_GKEY125                     327
#define IDB_GKEY126                     328
#define IDB_GKEY127                     329
#define IDB_GKEY128                     330
#define IDB_GKEY129                     331
#define IDB_GKEY130                     332
#define IDB_GKEY131                     333
#define IDB_GKEY132                     334
#define IDB_GKEY133                     335
#define IDB_GKEY134                     336
#define IDB_GKEY135                     337
#define IDB_GKEY136                     338
#define IDB_GKEY137                     339
#define IDB_GKEY138                     340
#define IDB_GKEY139                     341
#define IDB_GKEY140                     342
#define IDB_GKEY141                     343
#define IDB_GKEY142                     344
#define IDB_GKEY143                     345
#define IDB_GKEY144                     346
#define IDB_GKEY145                     347
#define IDB_GKEY146                     348
#define IDB_GKEY147                     349
#define IDB_GKEY148                     350
#define IDB_GKEY149                     351
#define IDB_GKEY150                     352
#define IDB_GKEY151                     353
#define IDB_GKEY152                     354
#define IDB_GKEY153                     355
#define IDB_GKEY154                     356
#define IDB_GKEY155                     357
#define IDB_GKEY156                     358
#define IDB_GKEY157                     359
#define IDB_GKEY158                     360
#define IDB_GKEY159                     361
#define IDB_GKEY160                     362
#define GALPHABETDIALOG                 363
#define GETSAVEDIALOG                   364
#define SAVELISTDIALOG                  365
#define IDC_WINCURSOR                   376
#define BGIMAGEDIALOG                   380
#define CSSDIALOG                       395
#define IDB_MATRIX                      397
#define ATTR4ITEMSDIALOG                398
#define IDB_GLINE                       401
#define IDB_GRECT                       402
#define IDB_GRRECT                      403
#define IDB_GCIRCLE                     404
#define IDB_GELLIPSE                    405
#define IDB_GPOLYLINE                   406
#define IDB_GCPOLYLINE                  407
#define IDB_GCURVE                      408
#define IDB_GCCURVE                     409
#define IDB_GALPHA1                     410
#define IDB_GALPHA2                     411
#define IDB_GGROUP                      412
#define GRAPHICSDIALOG                  413
#define ATTR2ITEMSDIALOG                415
#define TABLEDIALOG                     416
#define MATRIXDIALOG                    417
#define OPENIMAGEDIALOG                 418
#define GENERALMENU                     421
#define PUBLISHMENU                     482
#define CACHEMENU                       485
#define PROXYMENU                       486
#define GEOMETRYMENU                    499
#define COLORMENU                       502
#define GETALTERNATEDIALOG              505
#define LANNEGMENU                      509
#define TEMPLATESMENU                   513
#define PROFILEMENU                     519
#define MATH_ENTITY_DLG                 534
#define INITCONFIRM3LDIALOG             536
#define IDD_DIALOG3                     537
#define ATTR6ITEMSDIALOG                538
#define ATTR7ITEMSDIALOG                539
#define ATTR8ITEMSDIALOG                540
#define ATTR9ITEMSDIALOG                541
#define ANNOTMENU                       542
#define INITCONFIRM3LDIALOG1            543
#define ANNOTFILTERMENU                 544
#define MAKEIDMENU                      545
#define SAVEASDIALOG1                   546
#define DOCINFOMENU                     547
#define IDD_DIALOG1                     548
#define IDD_DIALOG2                     549
#define IDD_DIALOG4                     550
#define IDC_CURSOR1                     551
#define MIMETYPEDIALOG                  552
#define CHARSETDIALOG                   553
#define SAVEASDIALOG2                   554
#define ID_CONFIRM                      1000
#define ID_DONE                         1001
#define IDC_URLEDIT                     1002
#define ID_CHANGEMIMETYPE               1002
#define ID_CHANGECHARSET                1003
#define ID_PRINT                        1011
#define IDC_OPTIONS                     1012
#define IDC_TABOFCONTENTS               1014
#define IDC_LINKS                       1015
#define ID_NOREPLACE                    1024
#define IDC_SEARCHFOR                   1025
#define IDC_SEARCHEDIT                  1026
#define IDC_UPPERLOWER                  1027
#define IDC_REPLACEDBY                  1028
#define IDC_REPLACEDIT                  1029
#define IDC_REPLACEGROUP                1030
#define IDC_NOREPLACE                   1031
#define IDC_ONREQUEST                   1032
#define IDC_AUTOMATIC                   1033
#define IDC_BEFORE                      1035
#define IDC_WITHIN                      1036
#define IDC_AFTER                       1037
#define IDC_WHOLEDOC                    1038
#define ID_SAVEDOC                      1053
#define IDC_DONTSAVE                    1054
#define IDC_BROWSE                      1055
#define IDC_GETURL                      1056
#define IDC_URLMESSAGE                  1057
#define ID_APPLY                        1058
#define IDC_GETALT                      1058
#define IDC_CLEAR                       1058
#define IDC_TIMES                       1060
#define IDC_HELVETICA                   1061
#define IDC_COURIER                     1062
#define IDC_DEFAULTFAMILY               1063
#define IDC_ROMAN                       1065
#define IDC_BOLD                        1066
#define IDC_ITALIC                      1067
#define IDC_OBLIQUE                     1068
#define IDC_DEFAULTSTYLE                1071
#define IDC_NORMAL                      1073
#define IDC_UNDERLINE                   1074
#define IDC_CROSSOUT                    1075
#define IDC_OVERLINE                    1076
#define IDC_06PT                        1079
#define IDC_10PT                        1090
#define IDC_08PT                        1091
#define IDC_12PT                        1092
#define IDC_14PT                        1093
#define IDC_16PT                        1094
#define IDC_20PT                        1095
#define IDC_24PT                        1096
#define IDC_30PT                        1097
#define IDC_40PT                        1098
#define IDC_60PT                        1099
#define IDC_DEFAULTSIZE                 1100
#define IDC_LEFT                        1100
#define IDC_RIGHT                       1101
#define IDC_CENTER                      1102
#define IDC_JUSTIFY                     1103
#define IDC_BLEFT                       1104
#define IDC_BCENTER                     1106
#define IDC_BRIGHT                      1107
#define IDC_INDENTPT                    1108
#define IDC_INDENTPTVALUE               1109
#define IDC_DEFAULTALIGN                1110
#define IDC_INDENTPTEDIT                1111
#define IDC_INDENT1                     1113
#define IDC_INDENT2                     1114
#define IDC_INDENTDEFAULT               1115
#define IDC_BINDENT1                    1116
#define IDC_BINDENT2                    1118
#define IDC_BJUSTIFY                    1120
#define IDC_LINESPACINGPT               1123
#define IDC_LINESPACINGPTVALUE          1124
#define IDC_LINESPACINGEDIT             1125
#define IDC_SSMALL                      1127
#define IDC_SMEDIUM                     1129
#define IDC_SLARGE                      1130
#define IDC_SPACINGDEFAULT              1131
#define IDC_BSSMALL                     1132
#define IDC_BSMEDIUM                    1133
#define IDC_BSLARGE                     1134
#define ID_REPLACENEXT                  1135
#define ID_REPLACEDIC                   1136
#define ID_SKIPNEXT                     1138
#define ID_SKIPDIC                      1139
#define IDC_NBPROPOSALS                 1150
#define IDC_PROPOSALS                   1151
#define IDC_EDITPROPOSALS               1152
#define IDC_IGNORE1                     1154
#define IDC_IGNORE2                     1155
#define IDC_IGNORE3                     1156
#define IDC_IGNORE4                     1157
#define IDC_EDITIGNORE                  1158
#define ID_DELETE                       1162
#define ID_CLEAR                        1170
#define IDC_HTML                        1175
#define IDC_TEXT                        1176
#define IDC_COPYIMG                     1177
#define IDC_TRANSFORMURL                1178
#define IDC_DOCLOCATION                 1179
#define IDC_EDITDOCSAVE                 1180
#define IDC_IMGLOCATION                 1181
#define IDC_EDITIMGSAVE                 1182
#define IDC_NAMEEDIT                    1184
#define IDC_PASSWDEDIT                  1186
#define IDC_AUTHSERVER                  1189
#define IDC_AUTHREALM                   1190
#define IDC_LOGO                        1192
#define IDC_MATH                        1193
#define IDC_ROOT                        1195
#define IDC_SROOT                       1196
#define IDC_DIV                         1197
#define IDC_POWIND                      1198
#define IDC_POW                         1199
#define IDC_IND                         1200
#define IDC_UPDN                        1201
#define IDC_UP                          1202
#define IDC_DOWN                        1203
#define IDC_PAREXP                      1204
#define IDC_UDLR                        1205
#define IDC_SYM                         1206
#define IDC_MATRIX                      1207
#define IDC_GKEY002                     1209
#define IDC_GKEY003                     1210
#define IDC_GKEY004                     1211
#define IDC_GKEY005                     1212
#define IDC_GKEY006                     1213
#define IDC_GKEY007                     1214
#define IDC_GKEY008                     1215
#define IDC_GKEY001                     1216
#define IDC_GKEY009                     1217
#define IDC_GKEY010                     1218
#define IDC_GKEY011                     1219
#define IDC_GKEY012                     1220
#define IDC_GKEY013                     1221
#define IDC_GKEY014                     1222
#define IDC_GKEY015                     1223
#define IDC_GKEY016                     1224
#define IDC_GKEY017                     1225
#define IDC_GKEY018                     1226
#define IDC_GKEY019                     1227
#define IDC_GKEY020                     1228
#define IDC_GKEY021                     1229
#define IDC_GKEY022                     1230
#define IDC_GKEY023                     1231
#define IDC_GKEY024                     1232
#define IDC_GKEY025                     1233
#define IDC_GKEY026                     1234
#define IDC_GKEY027                     1235
#define IDC_GKEY028                     1236
#define IDC_GKEY029                     1237
#define IDC_GKEY030                     1238
#define IDC_GKEY031                     1239
#define IDC_GKEY032                     1240
#define IDC_GKEY033                     1241
#define IDC_GKEY034                     1242
#define IDC_GKEY035                     1243
#define IDC_GKEY036                     1244
#define IDC_GKEY037                     1245
#define IDC_GKEY038                     1246
#define IDC_GKEY039                     1247
#define IDC_GKEY040                     1248
#define IDC_GKEY041                     1249
#define IDC_GKEY042                     1250
#define IDC_GKEY043                     1251
#define IDC_GKEY044                     1252
#define IDC_GKEY045                     1253
#define IDC_GKEY046                     1254
#define IDC_GKEY047                     1255
#define IDC_GKEY048                     1256
#define IDC_GKEY049                     1257
#define IDC_GKEY050                     1258
#define IDC_GKEY051                     1259
#define IDC_GKEY052                     1260
#define IDC_GKEY053                     1261
#define IDC_GKEY054                     1262
#define IDC_GKEY055                     1263
#define IDC_GKEY056                     1264
#define IDC_GKEY057                     1265
#define IDC_GKEY058                     1266
#define IDC_GKEY059                     1267
#define IDC_GKEY060                     1268
#define IDC_GKEY061                     1269
#define IDC_GKEY062                     1270
#define IDC_GKEY063                     1271
#define IDC_GKEY064                     1272
#define IDC_GKEY065                     1273
#define IDC_GKEY066                     1274
#define IDC_GKEY067                     1275
#define IDC_GKEY068                     1276
#define IDC_GKEY069                     1277
#define IDC_GKEY070                     1278
#define IDC_GKEY071                     1279
#define IDC_GKEY072                     1280
#define IDC_GKEY073                     1281
#define IDC_GKEY074                     1282
#define IDC_GKEY075                     1283
#define IDC_GKEY076                     1284
#define IDC_GKEY077                     1285
#define IDC_GKEY078                     1286
#define IDC_GKEY079                     1287
#define IDC_GKEY080                     1288
#define IDC_GKEY081                     1289
#define IDC_GKEY082                     1290
#define IDC_GKEY083                     1291
#define IDC_GKEY084                     1292
#define IDC_GKEY085                     1293
#define IDC_GKEY086                     1294
#define IDC_GKEY087                     1295
#define IDC_GKEY088                     1296
#define IDC_GKEY089                     1297
#define IDC_GKEY090                     1298
#define IDC_GKEY091                     1299
#define IDC_GKEY092                     1300
#define IDC_GKEY093                     1301
#define IDC_GKEY094                     1302
#define IDC_GKEY095                     1303
#define IDC_GKEY096                     1304
#define IDC_GKEY097                     1305
#define IDC_GKEY098                     1306
#define IDC_GKEY099                     1307
#define IDC_GKEY100                     1308
#define IDC_GKEY101                     1309
#define IDC_GKEY102                     1310
#define IDC_GKEY103                     1311
#define IDC_GKEY104                     1312
#define IDC_GKEY105                     1313
#define IDC_GKEY106                     1314
#define IDC_GKEY107                     1315
#define IDC_GKEY108                     1316
#define IDC_GKEY109                     1317
#define IDC_GKEY110                     1318
#define IDC_GKEY111                     1319
#define IDC_GKEY112                     1320
#define IDC_GKEY113                     1321
#define IDC_GKEY114                     1322
#define IDC_GKEY115                     1323
#define IDC_GKEY116                     1324
#define IDC_GKEY117                     1325
#define IDC_GKEY118                     1326
#define IDC_GKEY119                     1327
#define IDC_GKEY120                     1328
#define IDC_GKEY121                     1329
#define IDC_GKEY122                     1330
#define IDC_GKEY123                     1331
#define IDC_GKEY124                     1332
#define IDC_GKEY125                     1333
#define IDC_GKEY126                     1334
#define IDC_GKEY127                     1335
#define IDC_GKEY128                     1336
#define IDC_GKEY129                     1337
#define IDC_GKEY130                     1338
#define IDC_GKEY131                     1339
#define IDC_GKEY132                     1340
#define IDC_GKEY133                     1341
#define IDC_GKEY134                     1342
#define IDC_GKEY135                     1343
#define IDC_GKEY136                     1344
#define IDC_GKEY137                     1345
#define IDC_GKEY138                     1346
#define IDC_GKEY139                     1347
#define IDC_GKEY140                     1348
#define IDC_GKEY141                     1349
#define IDC_GKEY142                     1350
#define IDC_GKEY143                     1351
#define IDC_GKEY144                     1352
#define IDC_GKEY145                     1353
#define IDC_GKEY146                     1354
#define IDC_GKEY147                     1355
#define IDC_GKEY148                     1356
#define IDC_GKEY149                     1357
#define IDC_GKEY150                     1358
#define IDC_GKEY151                     1359
#define IDC_GKEY152                     1360
#define IDC_GKEY153                     1361
#define IDC_GKEY154                     1362
#define IDC_GKEY155                     1363
#define IDC_GKEY156                     1364
#define IDC_GKEY157                     1365
#define IDC_GKEY158                     1366
#define IDC_GKEY159                     1367
#define IDC_GKEY160                     1368
#define IDC_MSG                         1372
#define IDC_OPENLOCATION                1377
#define IDC_BGLOCATION                  1378
#define IDC_REPEATMODE                  1380
#define IDC_REPEAT                      1381
#define IDC_REPEATX                     1382
#define IDC_REPEATY                     1383
#define IDC_NOREPEAT                    1384
#define IDC_XML                         1403
#define IDC_GRRECT                      1404
#define IDC_GELLIPSE                    1405
#define IDC_GLINE                       1406
#define IDC_GCPOLYLINE                  1407
#define IDC_GCIRCLE                     1408
#define IDC_GCCURVE                     1409
#define IDC_NUMCOL                      1409
#define IDC_GCURVE                      1410
#define IDC_NUMCOLEDIT                  1410
#define IDC_GRECT                       1411
#define IDC_NUMROWSEDIT                 1411
#define IDC_PRINTURL                    1411
#define IDC_GALPHA1                     1412
#define IDC_BORDEREDIT                  1412
#define IDC_ALTMESSAGE                  1412
#define IDC_IGNORE_CSS                  1412
#define IDC_GPOLYLINE                   1413
#define IDC_NUMROWS                     1413
#define IDC_DEFAULTUNDERLINE            1413
#define IDC_GALPHA2                     1414
#define IDC_BORDER                      1414
#define IDC_GGROUP                      1415
#define ID_DEFAULTS                     1417
#define IDC_HOMEPAGE                    1419
#define IDC_ZOOM                        1421
#define IDC_DIALOGUELANG                1422
#define IDC_MULTIKEY                    1423
#define IDC_BGIMAGES                    1424
#define IDC_DOUBLECLICK                 1425
#define IDC_ENABLEFTP                   1426
#define IDC_LOSTUPDATECHECK             1430
#define IDC_NOPROXY                     1430
#define IDC_VERIFYPUBLISH               1431
#define IDC_DEFAULTNAME                 1432
#define IDC_ENABLECACHE                 1433
#define IDC_SAFEPUTREDIRECT             1433
#define IDC_CACHEPROTECTEDDOCS          1434
#define IDC_CACHEDISCONNECTEDMODE       1435
#define IDC_CACHEEXPIREIGNORE           1436
#define IDC_CACHEDIRECTORY              1437
#define IDC_CACHESIZE                   1439
#define IDC_MAXCACHEFILE                1442
#define ID_FLUSHCACHE                   1443
#define IDC_HTTPPROXY                   1445
#define IDC_APPHOME                     1446
#define IDC_TMPDIR                      1447
#define IDC_FGCOLOR                     1450
#define IDC_BGCOLOR                     1451
#define IDC_ALTTEXT                     1452
#define IDC_SECOLOR                     1452
#define IDC_INCOLOR                     1453
#define IDC_CHANGCOLOR                  1454
#define IDC_CHANGCOLOR2                 1455
#define IDC_LANNEG                      1456
#define IDC_NORMALBOLD                  1457
#define IDC_DEFAULTBOLD                 1459
#define IDC_TEMPLATESURL                1460
#define IDC_PROFILESLOCATION            1462
#define IDC_PROFILENAME                 1463
#define IDC_PROXYDOMAIN                 1464
#define IDC_ONLYPROXY                   1465
#define IDC_FILTERBYSERVER              1466
#define IDC_ABOUT2                      1469
#define IDC_EDIT_NAME                   1470
#define IDC_VERSION                     1471
#define IDC_ENTITY_NAME                 1471
#define IDC_ABOUT1                      1472
#define IDC_IDC_TCACHEDIRECTORY         1472
#define IDC_TCACHESIZE                  1473
#define IDC_TMAXCACHEFILE               1474
#define IDC_THTTPPROXY                  1475
#define IDC_TPROXYDOMAIN                1476
#define IDC_TSEPENTRIESSPACE            1477
#define IDC_TAPPHOME                    1478
#define IDC_TTMPDIR                     1479
#define IDC_THOMEPAGE                   1480
#define IDC_TZOOM                       1481
#define IDC_TDIALOGUELANG               1482
#define IDC_TDEFAULTNAME                1483
#define IDC_TSAFEPUTREDIRECT            1484
#define IDC_TFGCOLOR                    1485
#define IDC_TBGCOLOR                    1486
#define IDC_GEOMCHANGE                  1487
#define IDC_TSECOLOR                    1487
#define IDC_TPROFILESLOCA               1488
#define IDC_TINCOLOR                    1488
#define IDC_TPROFILESELECT              1489
#define IDC_TPROFILECHANGE              1490
#define IDC_CSSFILES                    1491
#define IDC_MESSAGE1                    1492
#define IDC_MESSAGE2                    1493
#define IDC_MESSAGE3                    1494
#define IDC_CLOSEMSG                    1495
#define IDC_LANGELEM                    1496
#define IDC_INHERITEDLANG               1497
#define IDC_LNGEDIT                     1498
#define IDC_UNDERLINEGROUP              1499
#define IDC_FONTFAMILYGROUP             1500
#define IDC_CHARSTYLEGROUP              1501
#define IDC_BOLDGROUP                   1502
#define IDC_BODYSIZEGROUP               1503
#define IDC_LABEL                       1505
#define IDC_CURWORD                     1506
#define IDC_LANG                        1507
#define IDC_URL_TEXT                    1510
#define IDC_ANNOTUSER                   1511
#define IDC_TANNOTUSER                  1512
#define IDC_ANNOTSERVERS                1513
#define IDC_TANNOTSERVERS               1514
#define IDC_TANNOTPOSTSERVER            1515
#define IDC_ANNOTPOSTSERVER             1516
#define IDC_TANNOTAUTOLOAD              1518
#define IDC_ANNOTAUTOLOAD               1519
#define IDC_ANNOTLAUTOLOAD              1519
#define IDC_ANNOTRAUTOLOAD              1520
#define ID_ANNOTSHOW                    1521
#define IDC_ANNOTRAUTOLOADRST           1521
#define ID_ANNOTHIDE                    1522
#define ID_ANNOTSHOWALL                 1523
#define ID_ANNOTHIDEALL                 1524
#define IDC_FILTERBYAUTHOR              1525
#define IDC_FILTERBYTYPE                1526
#define IDC_TFILTEROPTIONS              1528
#define IDC_TFILTERHIDDEN               1529
#define IDC_TFILTERHELP                 1529
#define IDC_FILTERSEL                   1531
#define ID_CREATEID                     1533
#define ID_REMOVEID                     1534
#define IDC_IDC_TIDELEMNAME             1535
#define IDC_IDELEMNAME                  1536
#define IDC_IDAPPLYTODOC                1538
#define IDC_IDAPPLYTOSEL                1539
#define IDC_IDSTATUS                    1540
#define IDC_TAUTHREALM                  1542
#define IDC_TAUTHSERVER                 1543
#define IDC_TAUTHINFO                   1544
#define IDC_TPASSWDEDIT                 1545
#define IDC_TNAMEEDIT                   1546
#define IDC_AALT                        1547
#define IDC_ACTRL                       1548
#define IDC_ANONE                       1549
#define IDC_ACCESSKEY                   1550
#define IDC_DIURL                       1551
#define IDC_DICONTENTTYPE               1552
#define IDC_DICHARSET                   1553
#define IDC_DICONTENTLEN                1554
#define IDC_DICONTENTTYPE_VAL           1556
#define IDC_DICHARSET_VAL               1557
#define IDC_DICONTENTLEN_VAL            1558
#define IDC_DIURL_VAL                   1559
#define IDC_PAGENO                      1560
#define IDC_CHARSET                     1561
#define IDC_MIMETYPE                    1562
#define IDC_MTEDIT                      1564
#define IDC_STATUS                      1566
#define IDC_USASCII                     1567
#define IDC_UTF8                        1568
#define IDC_ISOL1                       1569
#define IDC_ISOL2                       1570
#define ID_BUTTON40017                  40017
#define ID_BUTTON40018                  40018
#define ID_BUTTON40019                  40019
#define ID_BUTTON40020                  40020
#define ID_BUTTON40022                  40022
#define ID_BUTTON40023                  40023
#define ID_BUTTON40024                  40024
#define ID_BUTTON40025                  40025
#define ID_BUTTON40026                  40026
#define ID_BUTTON40028                  40028
#define ID_BUTTON40029                  40029
#define ID_BUTTON40030                  40030
#define ID_BUTTON40031                  40031
#define ID_BUTTON40032                  40032
#define ID_BUTTON40033                  40033
#define ID_BUTTON40034                  40034
#define ID_BUTTON40035                  40035
#define ID_BUTTON40036                  40036
#define ID_BUTTON40038                  40038
#define ID_BUTTON40039                  40039
#define ID_BUTTON40040                  40040
#define ID_BUTTON40041                  40041
#define ID_BUTTON40042                  40042
#define ID_BUTTON40046                  40046
#define ID_BUTTON40047                  40047
#define ID_BUTTON40048                  40048
#define ID_BUTTON40049                  40049
#define ID_BUTTON40050                  40050
#define ID_BUTTON40051                  40051
#define IDC_CHECKGROUP                  65500
#define IDC_IGNOREGROUP                 65501
#define IDC_INDENTGROUP                 65530
#define IDCALIGNGROUP                   65531
#define IDC_JUSTIFGROUP                 65532
#define IDC_LINESPACEGROUP              65533
#define IDC_TLANNEG                     65535
#define IDC_TTEMPLATESURL               65535
#define IDC_WHEREGROUP                  65535
#define IDC_OUTPUTGROUP                 65535

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        554
#define _APS_NEXT_COMMAND_VALUE         40052
#define _APS_NEXT_CONTROL_VALUE         1570
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
